export interface AfterInterpolation {
    css: string;
    variableSuffix: string;
}
export interface BeforeInterpolation {
    css: string;
    variablePrefix: string;
}
/**
 * Extracts both prefix and suffix for CSS.
 *
 * This also handles the `url()` special case as interpolation does not work for this function.
 *
 * Prefix examples:
 * - `'"'` would return `'"'` as the suffix and `''` as the CSS.
 * - `'font-size: -` would return `'-'` as the suffix and `'font-size: '` as the CSS.
 * - `'color: blue'` would return `''` as the suffix and `'color: blue'` as the CSS.
 *
 * Suffix examples:
 * - `'px;font-size: 20px;'` would return `"px"` as the suffix and `";font-size: 20px;"` as the CSS.
 * - `'"'` would return `'"'` as the suffix and `''` as the CSS.
 * - `'notasuffix;'` would return `''` as the suffix and `'notasuffix;'` as the CSS.
 *
 *
 * @param before all the CSS _before_ the interpolation
 * @param after all the CSS _after_ the interpolation
 */
export declare const cssAffixInterpolation: (before: string, after: string) => [BeforeInterpolation, AfterInterpolation];
